@@ -1,14 +1,19 @@
+from abc import ABCMeta, abstractmethod
 from typing import List, Dict, Tuple, Any, Optional
 
 from .interface import Interface
 
 
-class IFitsHeaderAfter(Interface):
+class IFitsHeaderAfter(Interface, metaclass=ABCMeta):
     """The module provides some additional header entries for FITS headers after some event (usually the end of the
     exposure)."""
-    __module__ = 'pyobs.interfaces'
 
-    def get_fits_header_after(self, namespaces: Optional[List[str]] = None, **kwargs: Any) -> Dict[str, Tuple[Any, str]]:
+    __module__ = "pyobs.interfaces"
+
+    @abstractmethod
+    async def get_fits_header_after(
+        self, namespaces: Optional[List[str]] = None, **kwargs: Any
+    ) -> Dict[str, Tuple[Any, str]]:
         """Returns FITS header for the current status of this module.
 
         Args:
@@ -17,7 +22,7 @@ class IFitsHeaderAfter(Interface):
         Returns:
             Dictionary containing FITS headers.
         """
-        raise NotImplementedError
+        ...
 
 
-__all__ = ['IFitsHeaderAfter']
+__all__ = ["IFitsHeaderAfter"]
