@@ -7,7 +7,8 @@ from .interface import Interface
 class ISyncTarget(Interface, metaclass=ABCMeta):
     """The module can synchronize a target, e.g. via a telescope control software behinde an
     :class:`~pyobs.interfaces.ITelescope`."""
-    __module__ = 'pyobs.interfaces'
+
+    __module__ = "pyobs.interfaces"
 
     @abstractmethod
     async def sync_target(self, **kwargs: Any) -> None:
@@ -15,4 +16,4 @@ class ISyncTarget(Interface, metaclass=ABCMeta):
         ...
 
 
-__all__ = ['ISyncTarget']
+__all__ = ["ISyncTarget"]
