@@ -10,7 +10,8 @@ log = logging.getLogger(__name__)
 
 class FluentLogger(Module):
     """Log to fluentd server."""
-    __module__ = 'pyobs.modules.utils'
+
+    __module__ = "pyobs.modules.utils"
 
     def __init__(self, hostname: str, port: int, *args: Any, **kwargs: Any):
         """Initialize a new logger.
@@ -21,6 +22,7 @@ class FluentLogger(Module):
 
         """
         from fluent import sender
+
         Module.__init__(self, **kwargs)
 
         # store
@@ -28,18 +30,19 @@ class FluentLogger(Module):
         self._port = port
         self._fluent: Optional[sender.FluentSender] = None
 
-    def open(self) -> None:
+    async def open(self) -> None:
         """Open module."""
         from fluent import sender
-        Module.open(self)
+
+        await Module.open(self)
 
         # get handler
-        self._fluent = sender.FluentSender('pyobs', host=self._hostname, port=self._port)
+        self._fluent = sender.FluentSender("pyobs", host=self._hostname, port=self._port)
 
         # listen to log events
-        self.comm.register_event(LogEvent, self._process_log_entry)
+        await self.comm.register_event(LogEvent, self._process_log_entry)
 
-    def _process_log_entry(self, event: Event, sender: str) -> bool:
+    async def _process_log_entry(self, event: Event, sender: str) -> bool:
         """Process a new log entry.
 
         Args:
@@ -49,9 +52,9 @@ class FluentLogger(Module):
 
         # check
         if self._fluent is None:
-            raise ValueError('Module not opened.')
+            raise ValueError("Module not opened.")
         if not isinstance(event, LogEvent):
-            raise ValueError('Wrong event type.')
+            raise ValueError("Wrong event type.")
 
         # get time
         time = Time(event.time).unix
@@ -61,4 +64,4 @@ class FluentLogger(Module):
         return True
 
 
-__all__ = ['FluentLogger']
+__all__ = ["FluentLogger"]
