@@ -1,17 +1,17 @@
 from threading import Thread
 import logging
-
+from typing import Optional, Any, cast
 
 log = logging.getLogger(__name__)
 
 
 class ThreadWithReturnValue(Thread):
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args: Any, **kwargs: Any):
         Thread.__init__(self, *args, **kwargs)
-        self._return = None
-        self._exception = None
+        self._return: Optional[Any] = None
+        self._exception: Optional[Exception] = None
 
-    def run(self):
+    def run(self) -> None:
         if self._target is not None:
             try:
                 # save return valie
@@ -20,9 +20,9 @@ class ThreadWithReturnValue(Thread):
                 # save exception, if one was caught
                 self._exception = e
 
-    def join(self, timeout=None):
-        if timeout == 0.:
-            log.warning('Joining thread with timeout of 0s. Is this correct?')
+    def join(self, timeout: Optional[float] = None) -> Any:
+        if timeout is None:
+            log.warning("Joining thread with timeout of 0s. Is this correct?")
         # join thread
         Thread.join(self, timeout=timeout)
         # raise exception, if one was raised
@@ -32,4 +32,4 @@ class ThreadWithReturnValue(Thread):
         return self._return
 
 
-__all__ = ['ThreadWithReturnValue']
+__all__ = ["ThreadWithReturnValue"]
